#############################################################################
#
# MODULE:   	Grass Compilation
# AUTHOR(S):	Original author unknown - probably CERL
#		Markus Neteler - Germany/Italy - neteler@itc.it
#   	    	Justin Hickey - Thailand - jhickey@hpcc.nectec.or.th
#   	    	Huidae Cho - Korea - grass4u@gmail.com
#   	    	Eric G. Miller - egm2@jps.net
# PURPOSE:  	The source file for this Makefile is in src/CMD/head/head.in.
#		It is the top part of a file called make.rules which is used
#		for compiling all GRASS modules. This part of the file provides
#		make variables that are dependent on the results of the
#		configure script.
# COPYRIGHT:    (C) 2000 by the GRASS Development Team
#
#               This program is free software under the GNU General Public
#   	    	License (>=v2). Read the file COPYING that comes with GRASS
#   	    	for details.
#
#############################################################################

############################## Make Variables ###############################

CC                  = cc
#FC                  = @F77@
CXX                 = c++
LEX                 = flex
YACC                = bison -y
PERL                = /usr/bin/perl
AR                  = ar
RANLIB              = ranlib
MKDIR               = mkdir -p
CHMOD               = chmod
INSTALL             = /usr/bin/install -c -o root -g wheel 
INSTALL_DATA        = install  -o root -g wheel -m 444

prefix              = /usr/local
exec_prefix         = ${prefix}
ARCH                = amd64-portbld-freebsd7.3
UNIX_BIN            = ${exec_prefix}/bin
INST_DIR            = ${prefix}/grass-6.4.0

PLAT_OBJS           = 
STRIPFLAG           = 
CC_SEARCH_FLAGS     = -Wl,-rpath,${LIB_RUNTIME_DIR}
LD_SEARCH_FLAGS     = -rpath ${LIB_RUNTIME_DIR}
LD_LIBRARY_PATH_VAR = LD_LIBRARY_PATH
LIB_RUNTIME_DIR     = $(ARCH_LIBDIR)

#static libs:
STLIB_LD            = ${AR} cr
STLIB_PREFIX        = lib
STLIB_SUFFIX        = .a

#shared libs
SHLIB_PREFIX        = lib
SHLIB_LD            = ld -Bshareable -x
SHLIB_LD_EXTRAS     = 
SHLIB_LD_FLAGS      = 
SHLIB_LD_LIBS       = ${LIBS}
SHLIB_CFLAGS        = -fPIC
SHLIB_SUFFIX        = .so
EXE                 = 


# GRASS dirs
GRASS_HOME          = /work/a/ports/databases/grass/work/grass-6.4.0
RUN_GISBASE         = /work/a/ports/databases/grass/work/grass-6.4.0/dist.amd64-portbld-freebsd7.3
RUN_GISRC           = ${ARCH_DISTDIR}/demolocation/.grassrc${GRASS_VERSION_MAJOR}${GRASS_VERSION_MINOR}

DEFAULT_DATABASE    =
DEFAULT_LOCATION    =

CPPFLAGS            = -I/usr/local/include  -I/usr/local/include
CFLAGS1             = -O2 -fno-strict-aliasing -pipe 
CXXFLAGS1           = -O2 -fno-strict-aliasing -pipe
INCLUDE_DIRS        =  -I/usr/local/include

COMPILE_FLAGS       = $(CPPFLAGS) $(CFLAGS1) $(INCLUDE_DIRS)
COMPILE_FLAGS_CXX   = $(CPPFLAGS) $(CXXFLAGS1) $(INCLUDE_DIRS)
LINK_FLAGS          =  -L/usr/local/lib -export-dynamic  -L/usr/local/lib

DLLIB               = 
XCFLAGS             = 
XMINC               = 
XLIBPATH            = 
XLIB                =  -lSM -lICE -lX11
XTLIB               = -lXt
XMLIB               = 
XEXTRALIBS          = 
USE_X11             = 1

COMPATLIB           = -lcompat
CURSES              = -lncurses $(COMPATLIB)
USE_CURSES          = 1
MATHLIB             = -lm 
XDRLIB              =     -lz 
ICONVLIB            = -liconv
INTLLIB             = -lintl
SOCKLIB             = 

#ZLIB:
ZLIB                =    -lz 
ZLIBINCPATH         = 
ZLIBLIBPATH         = 

#DBM:
#DBMINCPATH          = @DBMINCPATH@
#DBMLIBPATH          = @DBMLIBPATH@
#DBMLIB              = @DBMLIB@
DBMIEXTRALIB        = -lcompat 

#readline
READLINEINCPATH     = 
READLINELIBPATH     = 
READLINELIB         =  -lreadline 
HISTORYLIB          =  -lhistory 

#PostgreSQL:
PQINCPATH           = 
PQLIBPATH           = 
PQLIB               = 

#MySQL:
MYSQLINCPATH        = 
MYSQLLIBPATH        = 
MYSQLLIB            = 
MYSQLDLIB            = 

#SQLite:
SQLITEINCPATH        = 
SQLITELIBPATH        = 
SQLITELIB            = 

#FFMPEG
FFMPEGINCPATH        = 
FFMPEGLIBPATH        = 
FFMPEGLIB            = 

#ODBC:
ODBCINC             = 
ODBCLIB             = 

#Image formats:
PNGINC              = 
PNGLIB              =  -lpng  -lz  -lm
USE_PNG             = 1

JPEGINCPATH         = 
JPEGLIBPATH         = 
JPEGLIB             =  -ljpeg 

TIFFINCPATH         = 
TIFFLIBPATH         = 
TIFFLIB             =  -ltiff 

#openGL files for NVIZ/r3.showdspf
OPENGLINC           =  -I/usr/local/include/
OPENGLWINC          = 
OPENGLLIB           =  -L/usr/local/lib/  -lGL 
OPENGLULIB          =  -L/usr/local/lib/  -lGLU 
OPENGLWM            = 
#USE_GLWM            = @USE_GLWM@
OPENGL_X11          = 1
OPENGL_AQUA         = 
OPENGL_WINDOWS      = 

#tcl/tk stuff
TCLINCDIR           =  -I/usr/local/include/tcl8.5 -I/usr/local/include/tk8.5
TKINCDIR            =  -I/usr/local/include/tcl8.5 -I/usr/local/include/tk8.5
TCLTKLIBPATH        = 
TCLTKLIBS           =  -ltk85 -lm  -ltcl85 -lm
TCLVERSION          = 8.5
MACOSX_ARCHS_TCLTK  = 

#FFTW:
FFTWINC             = 
FFTWLIB             =  -lfftw3 -lm

#LAPACK/BLAS stuff for gmath lib:
BLASLIB             = 
BLASINC				= 
LAPACKLIB           = 
LAPACKINC			= 

#GDAL/OGR
GDALLIBS            = -L/usr/local/lib -lgdal
GDALCFLAGS          = -I/usr/local/include
USE_GDAL            = 1
USE_OGR             = 1

#FreeType:
FTINC               =  -I/usr/local/include/freetype2
FTLIB               =  -lfreetype 

#PROJ.4:
PROJINC             =  $(GDALCFLAGS)
PROJLIB             =  -lproj 
NAD2BIN             = /usr/local/bin/nad2bin
PROJSHARE           = /usr/local/share/proj

#OPENDWG:
OPENDWGINCPATH      = 
OPENDWGLIBPATH      = 
OPENDWGLIB          = 
USE_OPENDWG         = 

#cairo
CAIROINC            = 
CAIROLIB            = 
USE_CAIRO           = 

#Python
PYTHONINC           = -I/usr/local/include/python2.6 -I/usr/local/include/python2.6
PYTHONCFLAGS        = -I/usr/local/include/python2.6 -I/usr/local/include/python2.6 -fno-strict-aliasing -O2 -fno-strict-aliasing -pipe -D__wchar_t=wchar_t -DTHREAD_STACK_SIZE=0x20000 -DNDEBUG -O2 -fno-strict-aliasing -pipe -D__wchar_t=wchar_t -DTHREAD_STACK_SIZE=0x20000
PYTHONLDFLAGS       = -L/usr/local/lib/python2.6/config -lutil -lm -lpython2.6
SWIG                = /usr/local/bin/swig
USE_PYTHON          = 1
MACOSX_ARCHS_PYTHON = 

#wxWidgets
WXVERSION           = 2.8.10
WXWIDGETSCXXFLAGS   = -I/usr/local/lib/wx/include/gtk2-ansi-release-2.8 -I/usr/local/include/wx-2.8 -D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D__WXGTK__ -pthread -D_THREAD_SAFE
WXWIDGETSCPPFLAGS   = -I/usr/local/lib/wx/include/gtk2-ansi-release-2.8 -I/usr/local/include/wx-2.8 -D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D__WXGTK__
WXWIDGETSLIB        = -L/usr/local/lib -pthread   -L/usr/local/lib   -lwx_gtk2_richtext-2.8 -lwx_gtk2_aui-2.8 -lwx_gtk2_xrc-2.8 -lwx_gtk2_qa-2.8 -lwx_gtk2_html-2.8 -lwx_gtk2_adv-2.8 -lwx_gtk2_core-2.8 -lwx_base_xml-2.8 -lwx_base_net-2.8 -lwx_base-2.8 
USE_WXWIDGETS       = 1
MACOSX_ARCHS_WXPYTHON = 

#regex
REGEXINCPATH        = 
REGEXLIBPATH        = 
REGEXLIB            =  
USE_REGEX           = 1

#i18N
HAVE_NLS            = 1

#Large File Support (LFS)
USE_LARGEFILES      = 1

#BSD sockets
HAVE_SOCKET         = 1

MINGW		    = 
MACOSX_APP	    = 
MACOSX_ARCHS    = 
MACOSX_SDK      = 

# Cross compilation
CROSS_COMPILING =  
